@@ -10,10 +10,11 @@ extern "C" fn safe_luaopen_socket_core(lua: *mut td_rlua::lua_State) -> libc::c_
         luaopen_socket_core(lua)
     }
 }
+
 /// custom lua load func
 extern "C" fn load_func(lua: *mut td_rlua::lua_State) -> libc::c_int {
     let path:String = td_rlua::LuaRead::lua_read(lua).unwrap_or(String::new());
-    if &path == "socket.core" || &path == "luasocket" {
+    if &path == "socket.core" || &path == "luasocket" || &path == "socket" {
         unsafe {
             td_rlua::lua_pushcfunction(lua, safe_luaopen_socket_core);
         }
@@ -22,7 +23,6 @@ extern "C" fn load_func(lua: *mut td_rlua::lua_State) -> libc::c_int {
     return 0;
 }
 
-pub fn enable_socket_core(lua : *mut td_rlua::lua_State) {
-    let mut lua = td_rlua::Lua::from_existing_state(lua, false);
+pub fn enable_socket_core(lua : &mut td_rlua::Lua) {
     lua.add_lualoader(load_func);
 }
\ No newline at end of file
